RsaIdValidator class

Validates South African ID numbers based on specified rules.

Constructors

RsaIdValidator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isValid(String idNumber) bool
Checks if the provided idNumber is a valid South African ID number.
isValidChecksum(String idNumber) bool
Validates the checksum part (Z) of a South African ID number using the Luhn algorithm.
isValidCitizenship(String citizenship) bool
Validates the citizenship part (C) of a South African ID number.
isValidDate(String yymmdd) bool
Validates the date part (YYMMDD) of a South African ID number.
isValidSequentialNumber(String sequentialNumber) bool
Validates the sequential number part (SSSS) of a South African ID number.